import processing.opengl.*;
import SMSlib.*;
import hardcorepawn.fog.fog;
import java.awt.event.*;

//---------- constants -------------------

//cam spherical coords: r=radius, f = x,y-angle and q = z-angle
float r=175.0, f=HALF_PI/2, q=HALF_PI/2;
//cam coords in cart. space
float x=50.0,y=50.0,z=50.0;
float rot_gain = 0.01;
float zoom_gain = 1;

//grid values
boolean drawGrid = true;

color XCol = color(255,0,0);
color YCol = color(0,255,0);
color ZCol = color(0,0,255);

//storage for data points
int dataPoints = 1000;
float[][] Histo = new float[dataPoints][3];
//current index
int Idx = 1;

float  zOffset = 1.031;    //adjust for earth's gravity at your location (should be around 1)


//drawing Histos
boolean drawLineG   = true;
boolean drawSphereG = true;

//fog
fog myFog; 
boolean drawFog = true;
int fog_nearVal = 150, fog_farVal = 300;
color fog_col = color(0,0,0);

//------------  functions  ---------------
void setup() {
  size(1024,768,OPENGL);
  if (drawFog){
    myFog=new fog(this);
    myFog.setupFog(fog_nearVal,fog_farVal);
    myFog.setColor(fog_col);
  }
  	
  frameRate(24);
  lights();
  smooth();
  
  //register mouseWheel listener
  addMouseWheelListener(new MouseWheelListener() { 
    public void mouseWheelMoved(MouseWheelEvent evt) { 
      mouseWheel(evt.getWheelRotation());
  }});
  recalcCamCoords();
}

void draw() {

  background(0);
  
  if (drawGrid) drawGrid();
  
  camera(x, y, z,  //coords
        0,0,0,    //lookat
        0,-1,0);  //up
  

  //store new reading into histo array
   Histo[Idx] = sms.getSMSArray();
   //and adjust the offset
   Histo[Idx][2] = Histo[Idx][2] + zOffset;

  //draw graphs
  if (drawLineG) drawLineGraph();
  if (drawSphereG) drawSphereG();
  
  //and advance index
  Idx = (Idx+1) % dataPoints;
  
  //draw fog
  if(drawFog)  myFog.doFog();
  
}

void mouseWheel(int delta) {
  r += zoom_gain * delta;
  if (r < 10) r = 10;
  
  recalcCamCoords();
}

void mouseDragged(){
  
  float rotX = mouseX-pmouseX;
  float rotY = mouseY-pmouseY;
  
 //adjust angles
 f += rot_gain * rotY;
 q += rot_gain * rotX;

 recalcCamCoords();
}

void recalcCamCoords(){
  //calc new cam coords
  x = r * sin(q) * cos(f);
  y = r * sin(q) * sin(f);
  z = r * cos(q);

}



